Description Usage Arguments Value
View source: R/SeuratCompareR.R
Uses Canonical Correlation Analysis to compare the expression profile of the identity classes of a Seurat object to those of a second Seurat object
1 2 3 4 5 6 7 8 9 | SeuratCompareR(first.obj, ...)
## S3 method for class 'seurat'
SeuratCompareR(first.obj, second.obj, group.by = NULL,
add.ident = NULL, cor.function.use = cor, do.plot = FALSE, ...)
## S3 method for class 'Seurat'
SeuratCompareR(first.obj, second.obj, group.by = NULL,
add.ident = NULL, cor.function.use = cor, do.plot = FALSE, ...)
|
first.obj |
Either a processed Seurat object (with ScaleData run) or the output from AverageExpression. If a Seurat object is passed, AverageExpression will be run. |
... |
Additional parameters to pass to the correlation function. |
second.obj |
A second (or the same) processed Seurat object or the output from AverageExpression for such an object. |
group.by |
Identifier or meta.data column by which to group the data. Default: 'ident' |
add.ident |
An additional identifier to use as a grouping variable. Default: NULL |
cor.function.use |
Function to use to calculate correlation. Default: stats::cor |
do.plot |
Plot the correlation matrix. Default: FALSE) |
A matrix of correlation values
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.